"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.compileClass = void 0;
const typescript_1 = __importDefault(require("typescript"));
const constants_1 = require("../constants");
const config_1 = require("../resolver/config");
const utils_1 = require("../utils");
const class_1 = require("./class");
const expression_1 = require("./expression");
const method_1 = require("./method");
const configResolver = new config_1.TsConfigResolver(utils_1.resolvePath(constants_1.ROOT, constants_1.TS_CONFIG_NAME));
const compileClass = (files, opts) => {
    const { sourceFiles, checker } = utils_1.getSourceFiles(files, configResolver.getCompilerOptions());
    let result = new Array();
    const visit = (node) => {
        if (typescript_1.default.isClassDeclaration(node)) {
            const className = class_1.getClassName(node);
            // According to includes and excludes to get qualified class
            if (!utils_1.isMatched(className, opts.includes) || utils_1.isMatched(className, opts.excludes)) {
                return;
            }
            const methods = class_1.getClassMethods(node);
            // Get all expression in method
            let expressions = new Array();
            methods.forEach((method) => {
                expressions = expressions.concat(method_1.getMethodEntry(method).expressions);
            });
            // Get request expressions
            expressions = expressions.filter((exp) => utils_1.isRequestExpression(exp));
            result = expressions.map((expression) => expression_1.serializeExpression(expression, checker));
        }
    };
    sourceFiles.forEach((sourceFile) => {
        if (!sourceFile.isDeclarationFile) {
            typescript_1.default.forEachChild(sourceFile, visit);
        }
    });
    return result;
};
exports.compileClass = compileClass;
