"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getMethodEntry = void 0;
/**
 * method => block => statement => expression
 */
const typescript_1 = __importDefault(require("typescript"));
const utils_1 = require("../utils");
/**
 * Get all CallExpression in method
 * @param node
 */
const getMethodEntry = (node) => {
    const entry = {};
    const methodBody = node.body;
    entry.name = typescript_1.default.isIdentifier(node.name) ? utils_1.getIdentifierText(node.name) : node.name.getText();
    if (methodBody && typescript_1.default.isBlock(methodBody)) {
        entry.expressions = processBlock(methodBody).filter((expression) => typescript_1.default.isCallExpression(expression));
    }
    return entry;
};
exports.getMethodEntry = getMethodEntry;
/**
 * Process block in statement
 * @param block
 */
const processBlock = (block) => {
    let expressions = new Array();
    block?.statements.forEach((statement) => {
        expressions = mergeExpressions(expressions, processStatement(statement));
    });
    return expressions;
};
/**
 * Get the ExpressionStatement and ReturnStatement in statement
 * @param statement
 */
const processStatement = (statement) => {
    if (typescript_1.default.isIfStatement(statement)) {
        return processIfStatement(statement);
    }
    else if (typescript_1.default.isExpressionStatement(statement) || typescript_1.default.isReturnStatement(statement)) {
        return statement.expression ? statement.expression : [];
    }
    return [];
};
/**
 * Process ifStatement
 * @param statement
 */
const processIfStatement = (statement) => {
    let expressions = new Array();
    // Process the expression contained in the block in the if
    if (typescript_1.default.isBlock(statement.thenStatement)) {
        expressions = mergeExpressions(expressions, processBlock(statement.thenStatement));
    }
    // When there is else
    // NOTE: when there is `else if`, the elseStatement here may also contain ifStatement
    if (statement.elseStatement) {
        if (typescript_1.default.isIfStatement(statement.elseStatement)) {
            // Process else if
            expressions = mergeExpressions(expressions, processIfStatement(statement.elseStatement));
        }
        else if (typescript_1.default.isBlock(statement.elseStatement)) {
            // Process else
            expressions = mergeExpressions(expressions, processBlock(statement.elseStatement));
        }
    }
    return expressions;
};
/**
 * Merge the expressions to a new array
 * @param target1
 * @param target2
 */
const mergeExpressions = (target1, target2) => {
    let result = new Array();
    Array.isArray(target1) ? (result = result.concat(target1)) : result.push(target1);
    Array.isArray(target2) ? (result = result.concat(target2)) : result.push(target2);
    return result;
};
