"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateMockData = void 0;
const faker_1 = __importDefault(require("faker"));
const utils_1 = require("../utils");
const getValueFromObject = (obj) => {
    let result = {};
    if (!Array.isArray(obj)) {
        Object.keys(obj).forEach((key) => {
            if (typeof obj[key] === 'object') {
                result[key] = getValueFromObject(obj[key]);
            }
            else {
                result[key] = generateBasicTypeValue(obj[key]);
            }
        });
    }
    else {
        return [getValueFromObject(obj[0])];
    }
    return result;
};
const generateBasicTypeValue = (valueType) => {
    switch (valueType) {
        case 'string':
            return faker_1.default.random.word();
        case 'string[]':
            return [faker_1.default.random.word()];
        case 'number':
            return faker_1.default.random.number();
        case 'number[]':
            return [faker_1.default.random.number()];
        default:
            return utils_1.toString(valueType);
    }
};
const isDifferent = (key, array) => array.indexOf(key) !== -1;
const generateMockData = (entry, originDataMap, differences) => {
    return entry.map(({ url, responseBody }) => {
        // When there is no change, take the original value directly
        if (differences.length > 0 && !isDifferent(url, differences)) {
            return originDataMap.get(url);
        }
        else {
            return {
                url,
                response: getValueFromObject(responseBody),
            };
        }
    });
};
exports.generateMockData = generateMockData;
