"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.requestMiddleware = exports.getOrGenerateMockData = void 0;
const mockData_1 = require("../resolver/mockData");
const utils_1 = require("../utils");
let mockData;
const getOrGenerateMockData = async (opts) => {
    const mockDataResolver = new mockData_1.MockDataResolver(opts);
    mockData = mockDataResolver.getOrGenerateData();
    return mockData;
};
exports.getOrGenerateMockData = getOrGenerateMockData;
utils_1.eventHub.sub('UPDATE_MOCK_DATA', (data) => {
    mockData = data;
});
const getTargetMockData = (url) => mockData.filter((data) => data.url === url);
const isGet = (method) => method && method.toUpperCase() === 'GET';
const requestMiddleware = async (req, res, next) => {
    let url = isGet(req.method) ? req.url?.split('?')[0] : req.url;
    const targetMockData = getTargetMockData(url);
    if (targetMockData.length > 0) {
        utils_1.logInfo(`invoke mock proxy: ${url}`);
        const data = targetMockData[0];
        if (data.timeout) {
            await utils_1.sleep(data.timeout);
        }
        res.setHeader('Content-Type', 'application/json');
        res.statusCode = data.httpCode ? data.httpCode : 200;
        res.end(JSON.stringify(data.response));
        return;
    }
    next();
};
exports.requestMiddleware = requestMiddleware;
