import ts from 'typescript';
import { InterfaceEntry } from '../compiler/interface';
export declare const getSourceFiles: (files: string[], opts: ts.CompilerOptions) => {
    sourceFiles: readonly ts.SourceFile[];
    checker: ts.TypeChecker;
};
/**
 * Get the value of escapedText in Identifier
 * @param identifier
 */
export declare const getIdentifierText: (identifier: ts.Identifier | undefined) => string;
/**
 * remove the `'` or `"`
 * @param value
 */
export declare const toString: (value: string) => string;
/**
 * Get the actual value of StringLiteral
 * @param node
 */
export declare const getStringLiteralValue: (node: ts.StringLiteral) => string;
/**
 * TypeReference to interface or generic string
 * @param node
 * @param checker
 */
export declare const processTypeReferenceNode: (node: ts.TypeReferenceNode | ts.LeftHandSideExpression | ts.TypeNode, checker: ts.TypeChecker) => InterfaceEntry | string;
/**
 * Determine whether CallExpression is a Request by METHODS
 * @param node
 */
export declare const isRequestExpression: (node: ts.CallExpression) => boolean;
/**
 * Recursively find the CallExpression of the leaf node in the AST
 *
 * such as:
 * The AST structure correspondence of `Request.get().then().then()`:
 *
 * CallExpression -- Request.get().then().then()
 *  PropertyAccessExpression
 *    CallExpression -- Request.get().then()
 *      PropertyAccessExpression
 *        CallExpression -- Request.get()
 *          PropertyAccessExpression
 *          TypeReference
 *
 * @param node
 */
export declare const getLeafCallExpression: (node: ts.CallExpression) => ts.CallExpression;
